==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all:
    Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("gvhpiegfiiggwach")
    public suspend
    fun all(`value`: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("uwaxxxuxvlcpvukc")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("qtlssibqtjvdglpg")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rvgtdhsbwsmqwcng")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nxylejbvnlfmagri")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("gmptgnogcuyfrjbm")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("eanrjxwiyxdmpngh")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("mispoadfcgdmjwpi")
    public suspend
    fun all(`value`: WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("iabheeoxvpbjdcnu")
    public suspend
    fun all(argument: suspend WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("qfrreptlclybbpdh")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("wrltyawwsgugvadw")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("fplbibatciddqemj")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("gfyenlqituhgwkla")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build():
        WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("httckypobmsymmfj")
    public suspend fun all(`value`: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("xpwjdkhjhdtrshcg")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("tpbsscnagbjxmktg")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("newjxprxwqdwglod")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pwofvmhnpqvcvkjq")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("ftxrwoupmhutgncj")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("eqxywntgrrrpxaew")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("vydudjeexpaiejim")
    public suspend fun all(`value`: WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("scwdyeoomrlrvmaj")
    public suspend fun all(argument: suspend WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("xvaknpwxfhplxggw")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("phxemtuxardbbtkh")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("lauqgtjfcldvhssq")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("tjxygjmwyldsodwx")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}
